;; Generated package description from do-at-point.el  -*- no-byte-compile: t -*-
(define-package "do-at-point" "0.1.0.0.20230922.101825" "Generic context-sensitive action dispatcher." '((emacs "26.1")) :commit "9f59dd6520f4417bd50efe32f4f35ecfc6bbea17" :authors '(("Philip Kaludercic" . "philipk@posteo.net")) :maintainer '("Philip Kaludercic" . "~pkal/public-inbox@lists.sr.ht") :keywords '("convenience") :url "https://git.sr.ht/~pkal/do-at-point")
